@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::DBI;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::DBI::VERSION = '1.101700';
+}
 # ABSTRACT: Mixin class for storages based on DBI
 
 # Mixin class for storages based on a transactional RDBMS. When deriving from
@@ -201,7 +203,7 @@ Data::Storage::DBI - Mixin class for storages based on DBI
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -266,7 +268,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
