@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::DBI::Oracle;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::DBI::Oracle::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for Oracle DBI storages
 use parent 'Data::Storage::DBI';
 
@@ -35,7 +37,7 @@ Data::Storage::DBI::Oracle - Base class for Oracle DBI storages
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -56,7 +58,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
