@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::DBI::Result;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::DBI::Result::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for DBI query results
 use DBI ':sql_types';
 use Error::Hierarchy::Util 'assert_defined';
@@ -41,7 +43,7 @@ Data::Storage::DBI::Result - Base class for DBI query results
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -66,7 +68,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
