@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Exception;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Exception::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for storage exceptions
 use parent qw(Error::Hierarchy Class::Accessor::Complex);
 1;
@@ -18,7 +20,7 @@ Data::Storage::Exception - Base class for storage exceptions
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 INSTALLATION
 
@@ -29,7 +31,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
