@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Filesystem;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Filesystem::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for filesystem-based storages
 use parent qw(Data::Storage Class::Accessor::Complex);
 use constant DEFAULTS => (mode => '0664');
@@ -92,7 +94,7 @@ Data::Storage::Filesystem - Base class for filesystem-based storages
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -137,7 +139,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
