@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Filesystem::Record;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Filesystem::Record::VERSION = '1.101700';
+}
 # ABSTRACT: A record from a filesystem-based storage
 use parent 'Class::Accessor::Complex';
 __PACKAGE__
@@ -22,7 +24,7 @@ Data::Storage::Filesystem::Record - A record from a filesystem-based storage
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 INSTALLATION
 
@@ -33,7 +35,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
