@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Memory;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Memory::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for memory-based storages
 use parent 'Data::Storage';
 sub connect { }
@@ -30,7 +32,7 @@ Data::Storage::Memory - Base class for memory-based storages
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -63,7 +65,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
