@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Mock;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Mock::VERSION = '1.101700';
+}
 # ABSTRACT: Base class for mock storages
 use parent qw(Data::Storage Class::Accessor::Complex);
 __PACKAGE__->mk_scalar_accessors(qw(should_die_on_connect));
@@ -39,7 +41,7 @@ Data::Storage::Mock - Base class for mock storages
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -76,7 +78,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
