@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Storage::Statement;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Storage::Statement::VERSION = '1.101700';
+}
 # ABSTRACT: Wrapper for DBI statements
 use Data::Miscellany 'value_of';
 use parent qw(Class::Accessor::Complex Class::Accessor::Constructor);
@@ -74,7 +76,7 @@ Data::Storage::Statement - Wrapper for DBI statements
 
 =head1 VERSION
 
-version 1.100850
+version 1.101700
 
 =head1 METHODS
 
@@ -107,7 +109,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Storage>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
